@@ -42,4 +42,4 @@ fips_state_table <- structure(list(abb = c("ak", "al", "ar", "as", "az", "ca", "
   packageStartupMessage("To enable \ncaching of data, set `options(tigris_use_cache = TRUE)` in your R script or .Rprofile.")
 }
 
-utils::globalVariables(c(".data", "geoid"))
+utils::globalVariables(c(".data", "geoid", "GEOID", "state_fips"))
